@@ -12,12 +12,12 @@ __license__ = 'Apache License 2.0'
 # Set module level logger.
 logger = logging.getLogger(__name__)
 
-def connect(remember_me=False, remember_me_always=False):
+def connect(config_file=False, remember_me=False, remember_me_always=False):
     """ Return a QGAPIConnect object for v1 API pulling settings from config
     file.
     """
     # Retrieve login credentials.
-    conf = qcconf.QualysConnectConfig(remember_me=remember_me, remember_me_always=remember_me_always)
+    conf = qcconf.QualysConnectConfig(filename=config_file, remember_me=remember_me, remember_me_always=remember_me_always)
     connect = qcconn.QGConnector(conf.get_username(),
                                   conf.get_password(),
                                   conf.get_hostname(),
